Index: src/compiler/pipeline.h |
diff --git a/src/compiler/pipeline.h b/src/compiler/pipeline.h |
index d437c7e585b1f4f2862820ba82894eb173d2548c..f71d2a1d4a67dc2b95a932df8c471ed3747519ea 100644 |
--- a/src/compiler/pipeline.h |
+++ b/src/compiler/pipeline.h |
@@ -30,11 +30,12 @@ class Pipeline { |
// Run the entire pipeline and generate a handle to a code object. |
Handle<Code> GenerateCode(); |
- // Run the pipeline on an interpreter bytecode handler machine graph and |
- // generate code. |
- static Handle<Code> GenerateCodeForInterpreter( |
- Isolate* isolate, CallDescriptor* call_descriptor, Graph* graph, |
- Schedule* schedule, const char* bytecode_name); |
+ // Run the pipeline on an code stub machine graph and generate code. |
Michael Starzinger
2015/12/01 18:06:53
nit: I know you didn't introduce this comment, but
danno
2015/12/02 07:00:19
Done.
|
+ static Handle<Code> GenerateCodeForCodeStub(Isolate* isolate, |
+ CallDescriptor* call_descriptor, |
+ Graph* graph, Schedule* schedule, |
+ Code::Kind kind, |
+ const char* bytecode_name); |
// Run the pipeline on a machine graph and generate code. If {schedule} is |
// {nullptr}, then compute a new schedule for code generation. |